# coding: utf-8

"""
    Mentortools Deep Agent API

    FastAPI service for running Mentortools deep agent

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from deep_agent_sdk.models.wrapped_response_tools_catalog_response import WrappedResponseToolsCatalogResponse  # noqa: E501

class TestWrappedResponseToolsCatalogResponse(unittest.TestCase):
    """WrappedResponseToolsCatalogResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseToolsCatalogResponse:
        """Test WrappedResponseToolsCatalogResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseToolsCatalogResponse`
        """
        model = WrappedResponseToolsCatalogResponse()  # noqa: E501
        if include_optional:
            return WrappedResponseToolsCatalogResponse(
                done = True,
                result = deep_agent_sdk.models.tools_catalog_response.ToolsCatalogResponse(
                    tools = [
                        deep_agent_sdk.models.catalog_tool_entry.CatalogToolEntry(
                            key = '', 
                            default_enabled = True, 
                            is_essential = True, )
                        ], )
            )
        else:
            return WrappedResponseToolsCatalogResponse(
                result = deep_agent_sdk.models.tools_catalog_response.ToolsCatalogResponse(
                    tools = [
                        deep_agent_sdk.models.catalog_tool_entry.CatalogToolEntry(
                            key = '', 
                            default_enabled = True, 
                            is_essential = True, )
                        ], ),
        )
        """

    def testWrappedResponseToolsCatalogResponse(self):
        """Test WrappedResponseToolsCatalogResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
