# coding: utf-8

"""
    Mentortools Deep Agent API

    FastAPI service for running Mentortools deep agent

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt

class RunChatContext(BaseModel):
    """
    Chat context for run creation.  # noqa: E501
    """
    id: StrictInt = Field(default=..., description="Chat ID (used internally as checkpointer thread_id)")
    chat_session_id: StrictInt = Field(default=..., description="Chat session ID (one exchange)")
    bot_chat_member_id: StrictInt = Field(default=..., description="Bot chat member ID")
    __properties = ["id", "chat_session_id", "bot_chat_member_id"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RunChatContext:
        """Create an instance of RunChatContext from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RunChatContext:
        """Create an instance of RunChatContext from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RunChatContext.parse_obj(obj)

        _obj = RunChatContext.parse_obj({
            "id": obj.get("id"),
            "chat_session_id": obj.get("chat_session_id"),
            "bot_chat_member_id": obj.get("bot_chat_member_id")
        })
        return _obj


